from typing import List

from bluer_options.terminal import show_usage


def help_get_ssid(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@wifi",
            "get_ssid",
        ],
        "get wifi ssid.",
        mono=mono,
    )


def help_copy_to_sd_card(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@wifi",
            "copy_to_sd_card",
        ],
        "copy wifi info to sd_card.",
        mono=mono,
    )


help_functions = {
    "get_ssid": help_get_ssid,
    "copy_to_sd_card": help_copy_to_sd_card,
}



import os

NAME = "bluer_ai"

ICON = "🌀"

DESCRIPTION = f"{ICON} A language to speak AI."

VERSION = "12.80.1"

REPO_NAME = "bluer-ai"

MARQUEE = "https://github.com/kamangir/assets/blob/main/awesome-bash-cli/marquee-2024-10-26.jpg?raw=true"


def fullname() -> str:
    bluer_ai_git_branch = os.getenv("bluer_ai_git_branch", "")
    return "{}-{}{}".format(
        NAME,
        VERSION,
        f"-{bluer_ai_git_branch}" if bluer_ai_git_branch else "",
    )



from typing import List

from bluer_options.terminal import show_usage


def help_timestamp(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@timestamp",
        ],
        "timestamp.",
        mono=mono,
    )


def help_timestamp_short(
    tokens: List[str],
    mono: bool,
) -> str:
    return show_usage(
        [
            "@@timestamp",
        ],
        "short timestamp.",
        mono=mono,
    )


help_functions = {
    "timestamp": {
        "": help_timestamp,
        "short": help_timestamp_short,
    }
}
